      Subroutine init(i,imax,ierr,                                              
     1 cdatloc,cdatnam,cdatid,cdatreg1,cdatreg2,cdatreg3,cdstamp)               
c                                                                               
      dll_export init                                                           
c                                                                               
c----------------------------------------------------------------------         
c --- DLL called from MSVB                                                      
c --- Special character-variable input processing for VB                        
c --- Date stamp of INIT contents added to arguments of call                    
c----------------------------------------------------------------------         
c                                                                               
c**********************************************************************         
c                                                                               
c --- COORDS     Version 1.0        101602                         INIT         
c 
c     Copyright (c) 2003-2007 by Exponent, Inc.
c                                                                              
c --- Program was written by Gary Moore at Earth Tech - Concord MA              
c                                                                               
c                                                                               
c
c --- Uses NIMA text file dated: 02-21-2003
c --- Uses BUILD version: VERSION 1.3
c --- Initializes the NIMA data label arrays                                    
c                                                                               
c----------------------------------------------------------------------         
c                                                                               
c --- Program notes                                                             
c                                                                               
c**********************************************************************         
c                                                                               
c --- Program function:                                                         
c                                                                               
c --- This program does some string housekeeping and outputs the strings        
c --- for use by a GUI or some other management routines. It starts             
c --- with the NIMA common blocks that are input via the NIMA.CRD include       
c --- block.                                                                    
c                                                                               
c --- Input arguments:                                                          
c                                                                               
c --- I = ith element desired                                                   
c                                                                               
c --- Output arguments - double precision                                       
c                                                                               
c --- IMAX = maximum number of elements in arrays                               
c --- IERR = FATAL error if not zero                                            
c --- DATID = 8 character ID code for each datum                                
c --- DATLOC = 20 character Atlas location string                               
c --- DATNAM = 52 character Datum name string                                   
c --- DATREG1 = 60 character Region descriptor string - line 1                  
c --- DATREG2 = 60 character Region descriptor string - line 2                  
c --- DATREG3 = 60 character Region descriptor string - line 3                  
c --- DSTAMP = 12 character date stamp for checking the NIMA file               
c                                                                               
c --- Subroutine calls:                                                         
c                                                                               
c --- None                                                                      
c                                                                               
c**********************************************************************         
c                                                                               
c --- Bring in the data arrays  (assigned via block data)                       
      INCLUDE 'nima.crd'                                                        
c                                                                               
c DLL Set character variables passed to/from VB                                 
      character(len=*) cdatloc                                                  
      character(len=*) cdatnam                                                  
      character(len=*) cdatid                                                   
      character(len=*) cdatreg1                                                 
      character(len=*) cdatreg2                                                 
      character(len=*) cdatreg3                                                 
      character(len=*) cdstamp                                                  
      logical ldb                                                               
      data ldb/.FALSE./                                                         
c      data ldb/.TRUE./                                                         
c DLL ---                                                                       
c                                                                               
      CHARACTER*8 DATID                                                         
      CHARACTER*20 DATLOC                                                       
      CHARACTER*52 ISTRNG, DATNAM                                               
      CHARACTER*60 DATREG1, DATREG2, DATREG3                                    
c                                                                               
c --- DLL DEBUG ---                                                             
      if(LDB) then                                                              
         open(22,file='init.see')                                               
         write(22,*)                                                            
         write(22,*)'Arguments as Input:'                                       
         write(22,*)'i,imax,ierr  = ',i,imax,ierr                               
         write(22,*)'cdatloc      = ',cdatloc                                   
         write(22,*)'cdatid       = ',cdatid                                    
         write(22,*)'cdatreg1     = ',cdatreg1                                  
         write(22,*)'cdatreg2     = ',cdatreg2                                  
         write(22,*)'cdatreg3     = ',cdatreg3                                  
         write(22,*)'cdstamp      = ',cdstamp                                   
         write(22,*)                                                            
         write(22,*)'Internal date variables:'                                  
         write(22,*)'dateb       = ',dateb                                      
         write(22,*)'daten       = ',daten                                      
         write(22,*)                                                            
      endif                                                                     
c                                                                               
c --- set max size                                                              
      imax = nd                                                                 
c                                                                               
c --- sets a 'finished' in DATID                                                
      DATID = 'finished'                                                        
c                                                                               
c --- Checks to see if array element is in range and that date                  
c --- stamp in BLOCK DATA (dateb) matches that in NIMA file (daten)             
      ierr = 0                                                                  
      if(i.lt.1.or.i.gt.nd)then                                                 
         ierr = 1                                                               
         if(LDB) then                                                           
            write(22,*)'Failed with ierr = ',ierr                               
            close(22)                                                           
         endif                                                                  
         return                                                                 
      elseif(dateb.ne.daten)then                                                
         ierr = 2                                                               
         if(LDB) then                                                           
            write(22,*)'Failed with ierr = ',ierr                               
            close(22)                                                           
         endif                                                                  
         return                                                                 
      endif                                                                     
c                                                                               
c --- First maps the DATLOC and DATNAM arrays                                   
      DATLOC = Atlas(dattyp(i))                                                 
      DATNAM = Datum(dattyp(i))                                                 
      DATID = Datcod(i)                                                         
      DATREG1 = Geodat1(i)                                                      
      DATREG2 = Geodat2(i)                                                      
      DATREG3 = Geodat3(i)                                                      
c                                                                               
c --- Now compresses the Datum name string                                      
      istrng = datnam                                                           
      Do j = 1,29                                                               
         jj = 29 - j + 1                                                        
         if(istrng(jj:jj).ne.' ')then                                           
            jbeg = jj + 2                                                       
            go to 444                                                           
         endif                                                                  
      Enddo                                                                     
444   continue                                                                  
      jend = jbeg + 22                                                          
      if(jend.gt.52)jend = 52                                                   
      istrng(jbeg:jend) = istrng(30:52)                                         
      if(jend.lt.52)then                                                        
         Do j = jend+1,52                                                       
            istrng(j:j) = ' '                                                   
         Enddo                                                                  
      endif                                                                     
      datnam = istrng                                                           
c                                                                               
c DLL Assign output strings                                                     
      cdatloc=DATLOC                                                            
      cdatnam=DATNAM                                                            
      cdatid=DATID                                                              
      cdatreg1=DATREG1                                                          
      cdatreg2=DATREG2                                                          
      cdatreg3=DATREG3                                                          
      cdstamp=DATEN                                                             
c                                                                               
c --- DLL DEBUG ---                                                             
      if(LDB) then                                                              
         write(22,*)                                                            
         write(22,*)'Arguments as Output:'                                      
         write(22,*)'i,imax,ierr  = ',i,imax,ierr                               
         write(22,*)'cdatloc      = ',cdatloc                                   
         write(22,*)'cdatid       = ',cdatid                                    
         write(22,*)'cdatreg1     = ',cdatreg1                                  
         write(22,*)'cdatreg2     = ',cdatreg2                                  
         write(22,*)'cdatreg3     = ',cdatreg3                                  
         write(22,*)'cdstamp      = ',cdstamp                                   
         write(22,*)                                                            
         close(22)                                                              
      endif                                                                     
c                                                                               
      Return                                                                    
      End                                                                       
c                                                                               
c-----------------------------------------------------------------------        
c --- Bring in BLOCK DATA as an include file                                    
c-----------------------------------------------------------------------        
      include 'blockdat.crd'                                                    
